<?php

/**
 * @package "Image Watermark" Addon for Elkarte
 * @author Spuds
 * @copyright (c) 2022 Spuds
 * @license This Source Code is subject to the terms of the Mozilla Public License
 * version 1.1 (the "License"). You can obtain a copy of the License at
 * http://mozilla.org/MPL/1.1/.
 *
 * @version 1.0.0
 *
 */

/**
 * Integrate actions hook, Integrate_actions, Called from dispatcher.class, used to add in custom actions
 *
 * @param mixed[] $actions
 */
function wm_ia(&$actions)
{
	global $modSettings;

	if (empty($modSettings['watermarkEnabled']))
	{
		return;
	}

	// If Watermark is enabled, points dlattach to the watermarks version of the method
	$actions['dlattach'] = array('Watermark.controller.php', 'Watermark_Controller', 'action_index');
}

/**
 * Help hook, integrate_quickhelp, called from help.controller.php
 *
 * Used to add in additional help languages for use in the admin quickhelp
 */
function wm_iqh()
{
	// Load the Watermark Help file.
	loadLanguage('Watermark');
}

/**
 * Admin Hook, integrate_admin_areas, called from Admin.php
 *
 * Used to add/modify admin menu areas
 *
 * @param mixed[] $admin_areas
 */
function wm_iaa(&$admin_areas)
{
	global $txt;

	loadLanguage('Watermark');

	$admin_areas['layout']['areas']['manageattachments']['subsections']['watermark'] = array($txt['watermark']);
}

/**
 * Attachments hook, integrate_sa_manage_attachments, called from Attachments.controller
 * used to add new attachment options.
 *
 * @param mixed[] $sub_actions
 */
function wm_isma(&$sub_actions)
{
	$sub_actions['watermark'] = array(
		'file' => 'WatermarkAdmin.controller.php',
		'controller' => 'WatermarkAdmin_Controller',
		'function' => 'action_index',
		'permission' => 'admin_forum'
	);
}
