<?php

/**
 * @package "Image Watermark" Addon for Elkarte
 * @author Spuds
 * @copyright (c) 2022 Spuds
 * @license This Source Code is subject to the terms of the Mozilla Public License
 * version 1.1 (the "License"). You can obtain a copy of the License at
 * http://mozilla.org/MPL/1.1/.
 *
 * @version 1.0.1
 *
 */

/**
 * WatermarkAdmin_Controller class, deals with site settings for Watermark functions
 */
class WatermarkAdmin_Controller extends Action_Controller
{
	public function pre_dispatch()
	{
		require_once(SUBSDIR . '/Watermark.subs.php');

		loadLanguage('Watermark');

		parent::pre_dispatch();
	}

	/**
	 * Entry point in Watermark controller
	 */
	public function action_index()
	{
		global $context, $txt;

		// Where to go?  Well we only have one choice
		$subActions = array(
			'watermark' => array($this, 'action_watermark')
		);

		$action = new Action();

		// Default action is .... watermark
		$subAction = $action->initialize($subActions, 'watermark');

		// Go!
		$context['page_title'] = $txt['manageposts_title'];
		$context['sub_action'] = $subAction;
		$action->dispatch($subAction);
	}

	/**
	 * Shows all available watermark settings
	 */
	public function action_watermark()
	{
		global $txt, $context, $scripturl;

		// Initialize the form
		$settingsForm = new Settings_Form(Settings_Form::DB_ADAPTER);
		$settingsForm->setConfigVars($this->_watermarkSettings());

		// Save them, show them
		if (isset($_GET['save']))
		{
			checkSession();
			$watermarkImages = watermarkDiscoverImages();

			$settingsForm->setConfigValues((array) $this->_req->post);
			$settingsForm->save();

			updateSettings(array('watermarkImageFile' => $watermarkImages[$_POST['watermarkImage']]));
			redirectexit('action=admin;area=manageattachments;sa=watermark');
		}

		// Setup the template
		$context['sub_template'] = 'show_settings';
		$context['page_title'] = $txt['watermark'];
		$context['post_url'] = $scripturl . '?action=admin;area=manageattachments;save;sa=watermark';
		$context['settings_title'] = $txt['watermark'];

		$settingsForm->prepare();
	}

	/**
	 * Return configuration settings
	 */
	private function _watermarkSettings()
	{
		global $txt;

		// These are the images we have available
		$watermarkImages = watermarkDiscoverImages();
		$check = class_exists('Imagick') && class_exists('ImagickDraw') && class_exists('ImagickPixel');
		$image = '';

		// Missing dependency, make sure this is off
		if (!$check)
		{
			updateSettings(array('watermarkEnabled' => 0));
		}
		else
		{
			$image = processWatermark(BOARDDIR . '/themes/default/images/watermark/admin_example.jpg', 'image/jpg', false);
		}

		return array(
			array('check', 'watermarkEnabled', 'postinput' => empty($check) ? $txt['watermarkImagick'] : '', 'disabled' => !$check),
			'',
			array('select', 'watermarkImage', $watermarkImages),
			array('text', 'watermarkScaleHeight', 'postinput' => $txt['px_%']),
			array('text', 'watermarkScaleWidth', 'postinput' => $txt['px_%']),
			'',
			array('text', 'watermarkText'),
			array('text', 'watermarkTextSize', 'postinput' => $txt['pt_%']),
			array('int', 'watermarkStrokeSize', 'postinput' => '( pt )'),
			'',
			array('int', 'watermarkMinHeight', 'postinput' => $txt['watermarkPixels']),
			array('int', 'watermarkMinWidth', 'postinput' => $txt['watermarkPixels']),
			array(
				'select', 'watermarkPosition', array(
					1 => $txt['watermarkPositionTopLeft'],
					$txt['watermarkPositionTopCenter'],
					$txt['watermarkPositionTopRight'],
					$txt['watermarkPositionCenterLeft'],
					$txt['watermarkPositionCenter'],
					$txt['watermarkPositionCenterRight'],
					$txt['watermarkPositionBottomLeft'],
					$txt['watermarkPositionBottomCenter'],
					$txt['watermarkPositionBottomRight'],
				),
			),
			'',
			array('check', 'name' => 'adminsample', 'disabled' => true,
				  $txt['watermarkTestExample'] . '<br><img src="data:image/jpg;base64,' . base64_encode($image->getImageBlob()) . '" />'),
		);
	}

	/**
	 * Return the settings for use in admin search
	 */
	public function settings_search()
	{
		return $this->_watermarkSettings();
	}
}
